================
How to run tests
================

This is a test app for the ``followit``.

To run tests, jump into directory containing this file,
add parent of ``followit`` directory to your ``PYTHONPATH``
environment variable:

    >PYTHONPATH=/path/to/parent_of_followit
    >export PYTHONPATH

Then launch the tests:

    >python runtests.py
